@@ -1,4 +1,4 @@
-//@line 40 "/mnt/Srcs/Firefox/build/toolkit/content/contentAreaUtils.js"
+//@line 40 "/home/karma/src/build/build/toolkit/content/contentAreaUtils.js"
 
 /**
  * urlSecurityCheck: JavaScript wrapper for checkLoadURIWithPrincipal
@@ -272,7 +272,7 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
                    saveAsType == kSaveAsType_Text) ?
                   "text/plain" : null,
     target      : fileURL,
-    postData    : isDocument ? getPostData() : null,
+    postData    : isDocument ? getPostData(aDocument) : null,
     bypassCache : aShouldBypassCache
   };
 
@@ -600,10 +600,13 @@ function appendFiltersForContentType(aFilePicker, aContentType, aFileExtension,
   aFilePicker.appendFilters(Components.interfaces.nsIFilePicker.filterAll);
 }
 
-function getPostData()
+function getPostData(aDocument)
 {
   try {
-    var sessionHistory = getWebNavigation().sessionHistory;
+    var sessionHistory = aDocument.defaultView
+                                  .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                                  .getInterface(Components.interfaces.nsIWebNavigation)
+                                  .sessionHistory;
     return sessionHistory.getEntryAtIndex(sessionHistory.index, false)
                          .QueryInterface(Components.interfaces.nsISHEntry)
                          .postData;
@@ -795,7 +798,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 840 "/mnt/Srcs/Firefox/build/toolkit/content/contentAreaUtils.js"
+//@line 843 "/home/karma/src/build/build/toolkit/content/contentAreaUtils.js"
 
   // Remove leading dots
   aFile = aFile.replace(/^\.+/, "");
